ModelConfig class

Constructors

ModelConfig({String? localRepositoryName, String? remoteRepositoryName, String? blocName, String? createViewName, String? listViewName})
const

Properties

blocName String?
final
createViewName String?
final
hashCode int
The hash code for this object.
no setterinherited
listViewName String?
final
localRepositoryName String?
final
remoteRepositoryName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited