Field class

Constructors

Field({required String name, required String type, List<String> annotations = const [], String? serializedName, bool isRequired = false, bool isEnum = false, String? example})

Properties

annotations List<String>
final
example String?
final
hashCode int
The hash code for this object.
no setterinherited
isEnum bool
final
isRequired bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializedName String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited