Model class
Constructors
-
Model({required String name, required List<
Field> fields, required List<EnumDefinition> enums, FileAttachment? fileAttachment})
Properties
-
enums
→ List<
EnumDefinition> -
final
-
fields
→ List<
Field> -
final
- fileAttachment → FileAttachment?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited